extern GdkPixmap *still_eyes_pixmap;
extern GdkPixmap *icon_blank_pixmap;
extern GdkPixmap *icon_message_pixmap;
extern GdkPixmap *icon_url_pixmap;
extern GdkPixmap *icon_auth_pixmap;
extern GdkPixmap *icon_away_pixmap;
extern GdkPixmap *icon_na_pixmap;
extern GdkPixmap *icon_occ_pixmap;
extern GdkPixmap *icon_dnd_pixmap;
extern GdkPixmap *icon_ffc_pixmap;
extern GdkPixmap *icon_inv_pixmap;
extern GdkPixmap *icon_online_pixmap;
extern GdkPixmap *icon_offline_pixmap;
extern GdkPixmap *icon_chat_pixmap;
extern GdkPixmap *icon_file_pixmap;
extern GdkPixmap *icon_info_pixmap;
extern GdkPixmap *icon_contact_pixmap;
extern GdkPixmap *icon_hist_pixmap;
extern GdkPixmap *icon_ok_pixmap;
extern GdkPixmap *icon_cancel_pixmap;
extern GdkPixmap *icon_rename_pixmap;

extern GdkBitmap *still_eyes_bitmap;
extern GdkBitmap *icon_blank_bitmap;
extern GdkBitmap *icon_message_bitmap;
extern GdkBitmap *icon_url_bitmap;
extern GdkBitmap *icon_auth_bitmap;
extern GdkBitmap *icon_away_bitmap;
extern GdkBitmap *icon_na_bitmap;
extern GdkBitmap *icon_occ_bitmap;
extern GdkBitmap *icon_dnd_bitmap;
extern GdkBitmap *icon_ffc_bitmap;
extern GdkBitmap *icon_inv_bitmap;
extern GdkBitmap *icon_online_bitmap;
extern GdkBitmap *icon_offline_bitmap;
extern GdkBitmap *icon_chat_bitmap;
extern GdkBitmap *icon_file_bitmap;
extern GdkBitmap *icon_info_bitmap;
extern GdkBitmap *icon_contact_bitmap;
extern GdkBitmap *icon_hist_bitmap;
extern GdkBitmap *icon_ok_bitmap;
extern GdkBitmap *icon_cancel_bitmap;
extern GdkBitmap *icon_rename_bitmap;
